#
# spec file for package python-keystoneauth1
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global sname keystoneauth1
Name:           python-keystoneauth1
Version:        2.12.1
Release:        2.15
Summary:        OpenStack authenticating tools
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://launchpad.net/%{sname}
Source0:        https://pypi.io/packages/source/k/%{sname}/%{sname}-%{version}.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python-PyYAML >= 3.1.0
BuildRequires:  python-betamax >= 0.7.0
BuildRequires:  python-fixtures >= 3.0.0
BuildRequires:  python-iso8601 >= 0.1.11
BuildRequires:  python-lxml >= 2.3
BuildRequires:  python-mock >= 2.0
BuildRequires:  python-oauthlib >= 0.6
BuildRequires:  python-oslo.config >= 3.14.0
BuildRequires:  python-oslo.utils >= 3.16.0
BuildRequires:  python-oslotest >= 1.10.0
BuildRequires:  python-pbr >= 1.6
BuildRequires:  python-pep8 >= 1.5.7
BuildRequires:  python-positional >= 1.0.1
BuildRequires:  python-pycrypto >= 2.6
BuildRequires:  python-reno >= 1.8.0
BuildRequires:  python-requests-kerberos >= 0.6
BuildRequires:  python-requests-mock >= 1.0
BuildRequires:  python-testrepository >= 0.0.18
BuildRequires:  python-testresources >= 0.2.4
BuildRequires:  python-testtools >= 1.4.0
Requires:       python-PyYAML >= 3.1.0
Requires:       python-iso8601 >= 0.1.11
Requires:       python-lxml >= 2.3
Requires:       python-oauthlib >= 0.6
Requires:       python-positional >= 1.0.1
Requires:       python-requests >= 2.10.0
Requires:       python-requests-kerberos >= 0.6
Requires:       python-six >= 1.9.0
Requires:       python-stevedore >= 1.16.0
BuildArch:      noarch

%description
Tools for authenticating to an OpenStack-based cloud. These tools include:
* Authentication plugins (password, token, and federation based)
* Discovery mechanisms to determine API version support
* A session that is used to maintain client settings across requests
  (based on the requests Python library)

%package doc
Summary:        Documentation for OpenStack authenticating tools
Group:          Development/Languages/Python
BuildRequires:  python-Sphinx
BuildRequires:  python-oslosphinx >= 2.5.0

%description doc
Documentation for OpenStack authenticating tools.

%prep
%setup -q -n %{sname}-%{version}

%build
%{py2_build}

%install
%{py2_install}

# generate html docs
%{__python2} setup.py build_sphinx
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%check
%{__python2} setup.py testr

%files
%license LICENSE
%doc AUTHORS ChangeLog README.rst
%{python2_sitelib}/%{sname}
%{python2_sitelib}/*.egg-info

%files doc
%doc doc/build/html
%license LICENSE

%changelog
* Wed Aug 31 2016 tbechtold@suse.com
  update to version 2.12.1
  * get_endpoint should return None when no version found
* Tue Aug 30 2016 tbechtold@suse.com
  update to version 2.12.0
  * Allow identity plugins to discover relative version urls
  * Disables TCP_KEEPCNT when using Windows Subsystem for Linux
  * User-agent header shouldn't start with a space
  * Add tests for user-agent with odd sys.argv
  * add status code 308 to _REDIRECT_STATUSES
  * Update the home-page in setup.cfg
  * Updated from global requirements
* Wed Aug 10 2016 tbechtold@suse.com
- update to version 2.11.0
  * Add tests for YamlJsonSerializer
  * Add missing class name to tuple of public objects
  * Fix arguments to _auth_required()
  * Don't include openstack/common in flake8 exclude list
  * Fix the doc error in "using-session"
  * Improve authentication plugins documentation
  * Use assertEqual() instead of assertDictEqual()
  * Updated from global requirements
  * Correctly report available for ADFS plugin
* Sun Aug  7 2016 dmueller@suse.com
- update to 2.10.0:
  * Lazy load oauthlib for plugin loading
  * oidc: add missing 'OidcAccessToken' to __all__
  * oidc: implement client_credentials grant type
  * Fix ECP doc link in Saml2 Password class doc
  * Updated from global requirements
  * Fix link for "extras dependencies" in extras doc
  * Add pretty serializer for betamax fixture
  * Update hacking to global-requirements value
  * Use SAML2 requests plugin
  * Updated from global requirements
  * oidc: move the get_unscoped_auth_ref into the base class
  * oidc: deprecate grant_type argument
  * oidc: add discovery document support
  * Add additional_headers to session and adapter
  * Add Python 3.5 classifier and venv
  * remove unused LOG
  * Updated from global requirements
  * Updated from global requirements
  * Add prompt parameter to Opt
  * Auth plugin for X.509 tokenless authentication
  * oidc: fix OpenID scope management
  * Add create_plugin to loader
* Mon Jul 11 2016 tbechtold@suse.com
- update to 2.9.0:
  * Updated from global requirements
  * move release note to correct directory
  * oidc: fix OpenID Connect scope option
  * oidc: add tests for plugin loader
  * Don't mock the session.request function
  * oidc: refactor unit tests
  * Fix code example for OAuth1 authentication
  * Add entrypoint for Federated Kerberos
  * Fix kerberos available property
  * Document named kerberos plugin
  * Support TOTP auth plugin
  * Make the kerberos plugin loadable
  * Add available flag to plugin loaders
  * PEP257: Ignore D203 because it was deprecated
  * Apply a heuristic for product name if a user_agent is not provided
* Sun Jun 19 2016 dmueller@suse.com
- update to 2.8.0:
  * Updated from global requirements
  * Let Oidc* auth plugins accept scope parameters as kwargs
  * Update keystoneauth fixture to support v3
  * Check that all defined entry points can be loaded
  * Use betamax hooks to mask fixture results
  * oidc: fix typo on class name
  * oidc: fix option definition
  * oidc: add OidcAccessToken class to authenticate reusing an access token
  * oidc: fix typo in docstring
  * oidc: DRY when obtaining an access token
  * oidc: DRY when obtaining a keystone token
  * oidc: Remove unused parameters in _OidcBase
  * Add is_domain to keystoneauth token
  * docstring: fix typo
  * Add oauth plugin to keystoneauth
  * Expose is_admin_project in AccessInfo
  * Expose allow parameters for URL discovery
  * Refactor variables for fixture and service
  * Enable bandit
  * Lazy import oslo_config as required
  * Add 303 as redirect code for k2k plugin
  * Updated from global requirements
  * Fix H405, D105, D200, and D203 PEP257
  * Updated from global requirements
  * Fixing D204, D205, D208, and D211 pep8
  * Fixing D301 docstring
  * Removing tox ignore D400
  * Fix documentation example again
  * Include query string in request logging
  * Removing tox ignore D401 and make keystoneauth compliant
* Mon Jun  6 2016 dmueller@suse.com
- switch to upstream maintained package
- update to 2.6.0:
  * Allow to send different recorders to betamax
  * Fix doc build if git is absent
  * Updated from global requirements
  * Updated from global requirements
  * fix OrderedDict mutated during iteration
  * Fix for PEP8 violation - D202 (No blank lines allowed after function docstring.)
  * Examples for migration from keystoneclient
  * Renamed endpoint to interface in docstring
  * Keystoneauth Authentication Plugin doc typo
  * Allow seeing full token response when debug enabled
  * Update reno for stable/mitaka
  * Examples for kerberos and saml2 plugins
  * Adding authentication compatibility for OpenStackClient
  * Swap the order of username deprecation
  * Fix exported symbol in identity.v3
  * Editorial nits for docs
  * Improve usability of docs
  * Add links to federation plugins
  * Remove unavailable parameter
  * Generate FederationBaseAuth constructor parameters
  * Update test run instructions
  * Fix typos and improve formatting in migrating.rst
  * Updated from global requirements
  * Updated from global requirements
  * Cleanup docstrings
  * Fix docstring in identity.v3.oidc module
  * Cleanup test-requirements.txt
  * Updated from global requirements
  * Allow parameter expansion in endpoint_override
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Use positional library instead of our own copy
  * Remove argparse from requirements
  * HTTPError should contain 'retry_after' parameter
  * Updated from global requirements
  * Remove keyring as a test-requiremnet
  * Mark password/secret options as secret
  * Replace deprecated library function os.popen() with subprocess
* Thu Mar  3 2016 tbechtold@suse.com
- update to 2.2.0:
  * add release notes for ksa 2.2.0
  * Updated from global requirements
  * Replace assertEqual(None, *) with assertIsNone in tests
  * Updated from global requirements
  * Change LOG.warn to LOG.warning
  * Wrong usage of "a"
  * On Windows and OSX, the 'socket' python module does not contain the attributes TCP_KEEPCNT or TCP_KEEPINTVL, causing services consuming the library to malfunction
  * Updated from global requirements
  * Add betamax to test-requirements.txt
  * Add some documentation about migrating from ksc
  * Docstring corrections
  * Iterate over copy of session.adapters keys in Python2/3
  * Provide a RFC 7231 compliant user agent string
  * Updated from global requirements
  * Deprecated tox -downloadcache option removed
  * small fix to missing parameters in documentation
  * Remove confusing documentation
  * Update coverage to keystoneauth1
  * Updated from global requirements
  * Cleanups to K2K plugin
  * Get versioned url for K2K auth
  * Extract SAML fixtures into templates
  * Add BetaMax Fixture
  * Updated from global requirements
- Switch to .spec from rpm-packaging upstream project
* Tue Dec  8 2015 bwiedemann@suse.com
- Update to version 2.1.0
  * Add oslo.config compatibility attributes
  * Default for service service type should be empty
  * Put py34 first in the env order of tox
  2.0.0
  - ----
  * Add release notes for keystoneauth
  * Add argparse registration from Adapter objects
  * Fix PEP 257 error
  * Remove Python 2.6 support
  * Tweak the way plugin attributes are loaded
  * Add load_from_options_getter to plugin loading
  * Cleanup time patching
  * Put Session options into an option group
  * Address hacking check H405
  * Allow saving and caching the plugin auth state
  * Add three pieces of the Session interface
  * Specify default_domain to generic plugin
  * Migrate kerberos plugin
  * Use XML matcher
  * Add XML matcher
  * Split ADFS and SAML2 plugins
  * SAML2 authentication plugins in keystoneauth
  * Correct references in authentication-plugin.rst
  * Declare an extras directory for plugins
  * Make public the base loader classes
  * Refactored AccessInfo.project_scoped accessor
  1.2.0
  - ----
  * Expose bind data via AccessInfo
  * Return None from generic plugin if failure
  * Fix deprecated options in oslo_config
  * Add url as a deprecated alias for endpoint
  * auto-generate release history
  * Make RST section delineation length match title
  * Remove "Features" section from README
  * Update the project description
  * Make __all__ immutable
  * Add UnknownConnectionError to __all__
  * remove references to keystone CLI
  * Add shields.io version/downloads links/badges into README.rst
  * Allow fetching oslo.config Opts from plugins
  * add openid connect plugins
  * Change ignore-errors to ignore_errors
* Sat Sep 26 2015 tbechtold@suse.com
- Initial packaging (version 1.1.0)
